import { renderless as renderless$1, api as api$1 } from '@opentinyvue/vue-renderless/scrollbar/vue';
import { defineComponent, $prefix, setup, h } from '@opentinyvue/vue-common';
import { calcScrollWidth, toObject } from '@opentinyvue/utils';
import { renderless, api } from '@opentinyvue/vue-renderless/scrollbar/vue-bar';
import '@opentinyvue/vue-theme/scrollbar/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script$1 = defineComponent({
  name: $prefix + "Bar",
  props: {
    vertical: Boolean,
    show: Boolean,
    size: String,
    move: Number
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true,
      h
    });
  },
  render: function render() {
    var h2 = arguments[0];
    var size = this.size, move = this.move, show = this.show, renderThumbStyle = this.renderThumbStyle, clickTrackHandler = this.clickTrackHandler, clickThumbHandler = this.clickThumbHandler, bar = this.state.bar;
    return h2("div", {
      "ref": "bar",
      "class": ["tiny-scrollbar__bar", "is-" + bar.key, show ? "is-show" : ""],
      "on": {
        "mousedown": clickTrackHandler
      }
    }, [h2("div", {
      "ref": "thumb",
      "class": "tiny-scrollbar__thumb",
      "on": {
        "mousedown": clickThumbHandler
      },
      "style": renderThumbStyle({
        bar,
        move,
        size
      })
    })]);
  }
});
var __vue2_render$1, __vue2_staticRenderFns$1;
var __cssModules$1 = {};
var __component__$1 = /* @__PURE__ */ normalizeComponent(__vue2_script$1, __vue2_render$1, __vue2_staticRenderFns$1, false, __vue2_injectStyles$1);
function __vue2_injectStyles$1(context) {
  for (var o in __cssModules$1) {
    this[o] = __cssModules$1[o];
  }
}
var Bar = /* @__PURE__ */ function() {
  return __component__$1.exports;
}();
var __vue2_script = defineComponent({
  name: $prefix + "Scrollbar",
  emits: ["mouseenter", "mousemove", "scroll"],
  components: {
    Bar
  },
  props: {
    marginBottomAdjust: {
      type: Number,
      default: 0
    },
    native: Boolean,
    // 如果container尺寸不会发生变化，最好设置它可以优化性能
    noresize: Boolean,
    // select 选择器下拉框数据过多时默认显示滚动条
    show: Boolean,
    tag: {
      type: String,
      default: "div"
    },
    viewClass: {},
    viewStyle: {},
    wrapClass: {},
    wrapStyle: {}
  },
  setup: function setup2(props, context) {
    return setup({
      props,
      context,
      renderless: renderless$1,
      api: api$1,
      mono: true
    });
  },
  render: function render2() {
    var _this = this;
    var h2 = arguments[0];
    var tag = this.tag, $slots = this.vm.$slots, native = this.native, wrapStyle = this.wrapStyle, wrapClass = this.wrapClass, viewStyle = this.viewStyle, viewClass = this.viewClass, handleScroll = this.handleScroll, state = this.state, show = this.show, marginBottomAdjust = this.marginBottomAdjust;
    var gutter = calcScrollWidth();
    var style = wrapStyle;
    if (gutter) {
      var gutterWith = "-" + gutter + "px";
      var gutterHeight = "-" + (gutter - marginBottomAdjust) + "px";
      var gutterStyle = "margin-bottom: " + gutterHeight + "; margin-right: " + gutterWith + ";";
      if (Array.isArray(wrapStyle)) {
        style = toObject(wrapStyle);
        style.marginRight = gutterWith;
        style.marginBottom = gutterHeight;
      } else if (typeof wrapStyle === "string") {
        style += gutterStyle;
      } else {
        style = gutterStyle;
      }
    }
    var view = h2(tag, {
      class: ["tiny-scrollbar__view", viewClass],
      style: viewStyle,
      ref: "resize"
    }, $slots.default ? $slots.default() : $slots.empty && $slots.empty());
    var wrap = h2("div", {
      "ref": "wrap",
      "style": style,
      "on": {
        "scroll": handleScroll
      },
      "class": [wrapClass, "tiny-scrollbar__wrap", gutter ? "" : "tiny-scrollbar__wrap--hidden-default"]
    }, [[view]]);
    var nodes;
    if (native) {
      nodes = [h2("div", {
        "ref": "wrap",
        "class": [wrapClass, "tiny-scrollbar__wrap"],
        "style": style
      }, [[view]])];
    } else {
      nodes = [wrap, h2(Bar, {
        "attrs": {
          "move": state.moveX,
          "size": state.sizeWidth,
          "show": show
        }
      }), h2(Bar, {
        "attrs": {
          "vertical": true,
          "move": state.moveY,
          "size": state.sizeHeight,
          "show": show
        }
      })];
    }
    return h2("div", {
      "class": "tiny-scrollbar",
      "on": {
        "mouseenter": function mouseenter(e) {
          _this.$emit("mouseenter", e);
        },
        "mousemove": function mousemove(e) {
          _this.$emit("mousemove", e);
        }
      }
    }, [nodes]);
  }
});
var __vue2_render, __vue2_staticRenderFns;
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, __vue2_render, __vue2_staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var Scrollbar = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.22.0";
Scrollbar.install = function(Vue) {
  Vue.component(Scrollbar.name, Scrollbar);
};
Scrollbar.version = version;

export { Scrollbar as default };
